==> qtcalculus_0.3-0maemo1.tar.gz: qtcalculus-0.3/src/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <Qt>
#include <QtGui>
#include "randomnumbers.h"

#define VERSION "0.1"

namespace Ui {
    class MainWindow;
}


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

private:
    Ui::MainWindow *ui;

    Item * currentItem;
    RandomNumbers * numbers;
    //QTimer * timer;

    void paintEvent(QPaintEvent* event);

    int ticks, fails;
    int number1;
    int number0;
    int result;
    int mode;
    int operation;

    QString current;

    int anim, animTimer;
    int tickTimer;
    bool showImage, wasOk;

    void set (char c);
    void confirm ();
    void think ();
    void ok ();
    void fail (int t);
    void clear ();

    void show1(int n);
    void show0(int n);
    void showResult(int n);
    void showOperation(int n);

protected:
    void timerEvent(QTimerEvent *event);

private slots:

	void onTick ();
    void options ();
    void about ();
    void donate ();
    void listenInactivity(QString s);
    void on_pushButton1_clicked();
    void on_pushButton0_clicked();
    void on_pushButton2_clicked();
    void on_pushButton3_clicked();
    void on_pushButton4_clicked();
    void on_pushButton5_clicked();
    void on_pushButton6_clicked();
    void on_pushButton8_clicked();
    void on_pushButton7_clicked();
    void on_pushButton9_clicked();
    void on_pushButtonCL_clicked();
    void on_pushButtonOK_clicked();
};

#endif // MAINWINDOW_H

==> qtcalculus_0.4-0maemo1.tar.gz: qtcalculus-0.4/src/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <Qt>
#include <QtGui>
#include "randomnumbers.h"

#define VERSION "0.1"

namespace Ui {
    class MainWindow;
}


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

private:
    Ui::MainWindow *ui;

    Item * currentItem;
    RandomNumbers * numbers;
    //QTimer * timer;

    void paintEvent(QPaintEvent* event);

    int ticks, fails;
    int number1;
    int number0;
    int result;
    int mode;
    int operation;

    QString current;

    int anim, animTimer;
    int tickTimer;
    bool showImage, wasOk, wasWrong;

    void set (char c);
    void confirm ();
    void think ();
    void ok ();
    void fail (int t);
    void clear ();

    void show1(int n, bool red);
    void show0(int n, bool red);
    void showResult(int n, bool red);
    void showOperation(int n);

protected:
    void timerEvent(QTimerEvent *event);

private slots:
    void orientationChanged(int o);
    void onTick ();
    void options ();
    void about ();
    void donate ();
    void listenInactivity(QString s);
    void on_pushButton1_clicked();
    void on_pushButton0_clicked();
    void on_pushButton2_clicked();
    void on_pushButton3_clicked();
    void on_pushButton4_clicked();
    void on_pushButton5_clicked();
    void on_pushButton6_clicked();
    void on_pushButton8_clicked();
    void on_pushButton7_clicked();
    void on_pushButton9_clicked();
    void on_pushButtonCL_clicked();
    void on_pushButtonOK_clicked();
};

#endif // MAINWINDOW_H
